## CSDN刷访客量——csdn_visitors

---

### csdn_visitors
- 快速刷取CSDN访客量
- 项目地址(欢迎star):[https://github.com/Amiee-well/csdn_visitors](https://github.com/Amiee-well/csdn_visitors)

### 使用方法
- pip install csdn_visitors

- 一行代码，将网址改为自己的url即可。

```python
__import__('csdn_visitors').CSDN.main("https://blog.csdn.net/qq_45414559")
```

- 网址务必为自己的CSDN网站。
